==> dasu_4.11.jar: edu/northwestern/dasu/sandbox/applet/RmiAMEServerInterface.java <==
/**
 * Dasu Project
 *
 * File:         RmiAMEServerInterface.java
 * RCS:          $Id: RmiAMEServerInterface.java,v 1.0 Oct 8, 2012 9:13:18 AM mas939 Exp $
 * Description:  RmiAMEServerInterface class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 8, 2012 at 9:13:18 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.ame
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox.applet;

import java.rmi.*;
import java.util.ArrayList;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RmiAMEServerInterface class ...
 */
public interface RmiAMEServerInterface extends Remote {

	public ArrayList<String> getAMExperiment(String SourceType) throws RemoteException;;
	
	public void AMECompleted(String engineId) throws RemoteException;
	
	public boolean isServerAlive() throws RemoteException;
	
}

==> dasu_5.1.jar: edu/northwestern/dasu/sandbox/applet/RmiAMEServerInterface.java <==
/**
 * Dasu Project
 *
 * File:         RmiAMEServerInterface.java
 * RCS:          $Id: RmiAMEServerInterface.java,v 1.0 Oct 8, 2012 9:13:18 AM mas939 Exp $
 * Description:  RmiAMEServerInterface class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 8, 2012 at 9:13:18 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement.ame
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox.applet;

import java.rmi.*;
import java.util.ArrayList;

import edu.northwestern.dasu.drools.ReportableFact;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RmiAMEServerInterface class ...
 */
public interface RmiAMEServerInterface extends Remote {

	public ArrayList<String> getAMExperiment(String SourceType) throws RemoteException;;
	
	public void AMECompleted(String engineId, boolean success) throws RemoteException;
	
	public boolean isServerAlive() throws RemoteException;
	
	public void commitReportableFact(ReportableFact fpr) throws RemoteException;
	
}
